% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statistic-scira.R
\name{run_scira}
\alias{run_scira}
\title{SCIRA (Single Cell Inference of Regulatory Activity)}
\usage{
run_scira(
  mat,
  network,
  .source = .data$tf,
  .target = .data$target,
  .mor = .data$mor,
  sparse = FALSE,
  fast = TRUE,
  center = TRUE,
  na.rm = FALSE
)
}
\arguments{
\item{mat}{Matrix to evaluate (e.g. expression matrix).
Target nodes in rows and conditions in columns.
\code{rownames(mat)} must have at least one intersection with the elements
in \code{network} \code{.target} column.}

\item{network}{Tibble or dataframe with edges and it's associated metadata.}

\item{.source}{Column with source nodes.}

\item{.target}{Column with target nodes.}

\item{.mor}{Column with edge mode of regulation (i.e. mor).}

\item{sparse}{Logical value indicating if the generated profile matrix
should be sparse.}

\item{fast}{Logical value indicating if the lineal model must be calculated
with \code{\link[speedglm:speedlm]{speedglm::speedlm.fit()}} or with base \code{\link[stats:lm]{stats::lm()}}.}

\item{center}{Logical value indicating if \code{mat} must be centered by
\code{\link[base:colSums]{base::rowMeans()}}.}

\item{na.rm}{Should missing values (including NaN) be omitted from the
calculations of \code{\link[base:colSums]{base::rowMeans()}}?}
}
\value{
A long format tibble of the enrichment scores for each tf
across the samples. Resulting tibble contains the following columns:
\enumerate{
\item \code{statistic}: Indicates which method is associated with which score.
\item \code{tf}: Source nodes of \code{network}.
\item \code{condition}: Condition representing each column of \code{mat}.
\item \code{score}: Regulatory activity (enrichment score).
}
}
\description{
Calculates TF activity according to
\href{https://www.nature.com/articles/s41525-020-00151-y?elqTrackId=d7efb03cf5174fe2ba84e1c34d602b13}{Improved detection of tumor suppressor events in single-cell RNA-Seq data}
.
}
\details{
Estimation of regulatory activity: A linear regression of the expression
profile is performed against the "target profile" of the given TF, where
in the target profile, any regulon member is assigned a \code{+1} for activating
interactions and a \code{-1} for inhibitory interactions. All other genes not
members of the TF's regulon are assigned a value o \code{0}. TF activity is then
defined as the t-statistic of this linear regression.
}
\examples{
inputs_dir <- system.file("testdata", "inputs", package = "decoupleR")

mat <- readRDS(file.path(inputs_dir, "input-expr_matrix.rds"))
network <- readRDS(file.path(inputs_dir, "input-dorothea_genesets.rds"))

run_scira(mat, network, tf, target, mor)
}
\seealso{
Other decoupleR statistics: 
\code{\link{decouple}()},
\code{\link{run_gsva}()},
\code{\link{run_mean}()},
\code{\link{run_ora}()},
\code{\link{run_pscira}()},
\code{\link{run_viper}()}
}
\concept{decoupleR statistics}
