% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/statistic-viper.R
\name{run_viper}
\alias{run_viper}
\title{VIPER wrapper}
\usage{
run_viper(
  mat,
  network,
  .source = .data$tf,
  .target = .data$target,
  .mor = .data$mor,
  .likelihood = .data$likelihood,
  ...
)
}
\arguments{
\item{mat}{Matrix to evaluate (e.g. expression matrix).
Target nodes in rows and conditions in columns.
\code{rownames(mat)} must have at least one intersection with the elements
in \code{network} \code{.target} column.}

\item{network}{Tibble or dataframe with edges and it's associated metadata.}

\item{.source}{Column with source nodes.}

\item{.target}{Column with target nodes.}

\item{.mor}{Column with edge mode of regulation (i.e. mor).}

\item{.likelihood}{Column with edge likelihood.}

\item{...}{
  Arguments passed on to \code{\link[viper:viper]{viper::viper}}
  \describe{
    \item{\code{dnull}}{Numeric matrix for the null model, usually generated by \code{nullTtest}}
    \item{\code{pleiotropy}}{Logical, whether correction for pleiotropic regulation should be performed}
    \item{\code{nes}}{Logical, whether the enrichment score reported should be normalized}
    \item{\code{method}}{Character string indicating the method for computing the single samples signature, either scale, rank, mad, ttest or none}
    \item{\code{bootstraps}}{Integer indicating the number of bootstraps iterations to perform. Only the scale method is implemented with bootstraps.}
    \item{\code{adaptive.size}}{Logical, whether the weighting scores should be taken into account for computing the regulon size}
    \item{\code{eset.filter}}{Logical, whether the dataset should be limited only to the genes represented in the interactome
#' @param mvws Number or vector indicating either the exponent score for the metaViper weights, or the inflection point and trend for the sigmoid function describing the weights in metaViper}
    \item{\code{pleiotropyArgs}}{list of 5 numbers for the pleotropy correction indicating: regulators p-value threshold, pleiotropic interaction p-value threshold, minimum number of targets in the overlap between pleiotropic regulators, penalty for the pleiotropic interactions and the method for computing the pleiotropy, either absolute or adaptive}
    \item{\code{cores}}{Integer indicating the number of cores to use (only 1 in Windows-based systems)}
    \item{\code{verbose}}{Logical, whether progression messages should be printed in the terminal}
  }}
}
\value{
A long format tibble of the enrichment scores for each tf
across the samples. Resulting tibble contains the following columns:
\enumerate{
\item \code{statistic}: Indicates which method is associated with which score.
\item \code{tf}: Source nodes of \code{network}.
\item \code{condition}: Condition representing each column of \code{mat}.
\item \code{score}: Regulatory activity (enrichment score).
}
}
\description{
This function is a convenient wrapper for the \code{\link[viper:viper]{viper::viper()}} function.
}
\examples{
inputs_dir <- system.file("testdata", "inputs", package = "decoupleR")

mat <- readRDS(file.path(inputs_dir, "input-expr_matrix.rds"))
network <- readRDS(file.path(inputs_dir, "input-dorothea_genesets.rds"))

run_viper(mat, network, tf, target, mor, likelihood, verbose = FALSE)
}
\seealso{
Other decoupleR statistics: 
\code{\link{decouple}()},
\code{\link{run_gsva}()},
\code{\link{run_mean}()},
\code{\link{run_ora}()},
\code{\link{run_pscira}()},
\code{\link{run_scira}()}
}
\concept{decoupleR statistics}
